@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ public:
     ~BlogiloComposerWebEngineView();
 
     void startEditing();
-    void addExtraAction(QMenu *menu) Q_DECL_OVERRIDE;
+    void addExtraAction(QMenu *menu) override;
 
     void setCustomTools(PimCommon::CustomToolsWidgetNg *customTool);
 
